import network                               # https://micropython-docs-esp32.readthedocs.io/en/esp32_doc/esp32/quickref.html#networking
ap = network.WLAN(network.AP_IF)             # create access-point interface
ap.active(True)                              # activate the interface
ap.config(essid='ESP32-AccessPoint')         # set the ESSID of the AP
ap.config(authmode=3, password='12345678')   # set the authmode (0=open 1=WEP 2=WPA-PSK 3=WPA2-PSK 4=WPA/WPA2-PSK) and password

import machine
pins = [machine.Pin(i, machine.Pin.IN) for i in (0, 2, 4, 5, 12, 13, 14, 15)]
 
html = """<!DOCTYPE html>
<html>
    <head> <title>ESP32 Pins</title> </head>
    <body> <h1>ESP32 Pins</h1>
        <table border="1"> <tr><th>Pin</th><th>Value</th></tr> %s </table>
    </body>
</html>
"""
 
import socket
addr = socket.getaddrinfo('0.0.0.0', 80)[0][-1]
 
s = socket.socket()
s.bind(addr)
s.listen(1)
 
print('listening on', addr)
 
while True:
    cl, addr = s.accept()
    print('client connected from', addr)
    cl_file = cl.makefile('rwb', 0)
    while True:
        line = cl_file.readline()
        if not line or line == b'\r\n':
            break
    rows = ['<tr><td>%s</td><td>%d</td></tr>' % (str(p), p.value()) for p in pins]
    response = html % '\n'.join(rows)
    cl.send(response)
    cl.close()